@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.5.0";
+$Mojo::Webqq::VERSION = "1.5.1";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -10,10 +10,12 @@ use POSIX;
 use File::Spec ();
 use base qw(Mojo::EventEmitter Mojo::Webqq::Base Mojo::Webqq::Model Mojo::Webqq::Client Mojo::Webqq::Message Mojo::Webqq::Plugin);
 
+has qq                     => undef;
+has pwd                    => undef;
 has security                => 0;
 has state                   => 'online';   #online|away|busy|silent|hidden|offline,
 has type                    => 'smartqq';  #smartqq
-has login_type              => 'login';    #qrlogin|login
+has login_type              => 'qrlogin';    #qrlogin|login
 has ua_debug                => 0;
 has log_level               => 'info';     #debug|info|warn|error|fatal
 has log_path                => undef;
@@ -24,9 +26,7 @@ has encrypt_method          => "perl";     #perl|js
 has verifycode_path         => undef;
 has qrcode_path             => undef;
 has tmpdir                  => sub {File::Spec->tmpdir();};
-has pic_dir                 => undef;
-has friend_pic_dir          => sub{return $_[0]->pic_dir};
-has group_pic_dir           => sub{return $_[0]->pic_dir};
+has pic_dir                 => sub {$_[0]->tmpdir};
 has ioloop                  => sub{Mojo::IOLoop->singleton};
 has keep_cookie             => 1;
 has cookie_dir              => sub{
@@ -35,9 +35,9 @@ has cookie_dir              => sub{
     }
     else{return undef}
 };
+has max_recent => 20;
 
 has version                 => $Mojo::Webqq::VERSION;
-
 has user    => sub {+{}};
 has friend  => sub {[]};
 has recent  => sub {[]};
@@ -97,8 +97,6 @@ has ua                      => sub {
     );
 };
 
-has qq                     => undef;
-has pwd                    => undef;
 has is_need_img_verifycode => 0;
 has img_verifycode_source  => 'TTY';             #NONE|TTY|CALLBACK
 has send_msg_id            => sub {
@@ -129,6 +127,12 @@ has g_appid                => 1003903;
 has g_pt_version           => 10092;
 has rc                     => 1;
 
+sub new {
+    my $class = shift;
+    my $self  = $class->SUPER::new(@_);
+    $ENV{MOJO_USERAGENT_DEBUG} = $self->{ua_debug};
+    $self;
+}
 sub on {
     my $self = shift;
     while(@_){
